walk

Function walk 

pub fn walk(root: &str, ext: Option<&str>) -> Vec<Entry>
Recursively crawl root (a ~-expandable path). ext, when given, keeps only files with that extension (no leading dot). Capped internally so a crawl of a huge tree can’t run away.